==> com.liferay.portal.osgi.debug.missing.component-2.0.4-sources-commercial.jar: com/liferay/portal/osgi/debug/missing/component/internal/MissingComponentSystemChecker.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.osgi.debug.missing.component.internal;

import com.liferay.portal.osgi.debug.SystemChecker;

import org.osgi.framework.BundleContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.runtime.ServiceComponentRuntime;

/**
 * @author Matthew Tambara
 */
@Component(immediate = true, service = SystemChecker.class)
public class MissingComponentSystemChecker implements SystemChecker {

	@Override
	public String check() {
		return MissingComponentUtil.scan(
			_bundleContext, _serviceComponentRuntime);
	}

	@Override
	public String getName() {
		return "Missing Component Scanner";
	}

	@Override
	public String getOSGiCommand() {
		return "ds:missing";
	}

	@Override
	public String toString() {
		return getName();
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_bundleContext = bundleContext;
	}

	private BundleContext _bundleContext;

	@Reference
	private ServiceComponentRuntime _serviceComponentRuntime;

}

==> com.liferay.portal.osgi.debug.missing.component-2.0.8-sources-commercial.jar: com/liferay/portal/osgi/debug/missing/component/internal/MissingComponentSystemChecker.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.osgi.debug.missing.component.internal;

import com.liferay.portal.osgi.debug.SystemChecker;

import org.osgi.framework.BundleContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.runtime.ServiceComponentRuntime;

/**
 * @author Matthew Tambara
 */
@Component(service = SystemChecker.class)
public class MissingComponentSystemChecker implements SystemChecker {

	@Override
	public String check() {
		return MissingComponentUtil.scan(
			_bundleContext, _serviceComponentRuntime);
	}

	@Override
	public String getName() {
		return "Missing Component Scanner";
	}

	@Override
	public String getOSGiCommand() {
		return "ds:missing";
	}

	@Override
	public String toString() {
		return getName();
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_bundleContext = bundleContext;
	}

	private BundleContext _bundleContext;

	@Reference
	private ServiceComponentRuntime _serviceComponentRuntime;

}
